/*
 *  file:     m392defs.h
 *  revision: 1.1
 *  date:     03/01/00
 *  author:   JG
 * ----------------------------------------------------------------------
 *
 * M392 12-/16-bit ADC M-module with 16x Single Ended Inputs
 * ANSI-C library definitions
 *
 * This header file contains the general definitions for m392lib.c
 * and m392demo.c
 *
 * ----------------------------------------------------------------------
 * Copyright 2000-2001 by AcQuisition Technology bv (c)
 * All Rights Reserved
 * Reproduced Under License
 *
 * This source code is the proprietary confidential property of
 * AcQuisition Technology bv, and is provided to the licensee
 * for documentation and educational purposes only.  Reproduction,
 * publication, or any form of distribution to any party other than
 * the licensee is strictly prohibited.
 * ----------------------------------------------------------------------
 * Edition History
 *
 * #    date        Comments                                        by
 * --   --------    ----------------------------------------------  ---
 * 1.0  03-01-00    First release                                   JG
 * 1.1  03-05-01    Definitions of global status word added         SP
 *
 */
#ifndef __INCm392defsh
#define __INCm392defsh

#include "apis.h"

#define TRUE    1
#define FALSE   0

#define NCH     16      /* number of input channels */

/*
 * M392 Memory map
 *
 *  Host register definitions (offsets to module's base address)
 *  communication structures definitions (resides in dual ported SRAM)
 */
#define MDR0    0x0000          /* measurement data channel 0 */
#define MDR1    0x0002          /* measurement data channel 1 */
#define MDR2    0x0004          /* measurement data channel 2 */
#define MDR3    0x0006          /* measurement data channel 3 */
#define MDR4    0x0008          /* measurement data channel 4 */
#define MDR5    0x000A          /* measurement data channel 5 */
#define MDR6    0x000C          /* measurement data channel 6 */
#define MDR7    0x000E          /* measurement data channel 7 */
#define MDR8    0x0010          /* measurement data channel 8 */
#define MDR9    0x0012          /* measurement data channel 9 */
#define MDR10   0x0014          /* measurement data channel 10 */
#define MDR11   0x0016          /* measurement data channel 11 */
#define MDR12   0x0018          /* measurement data channel 12 */
#define MDR13   0x001A          /* measurement data channel 13 */
#define MDR14   0x001C          /* measurement data channel 14 */
#define MDR15   0x001E          /* measurement data channel 15 */

#define C_CMD       0x0040      /* command */
#define C_RES       0x0042      /* execution result */
#define C_PRM0      0x0044      /* parameter 0 */
#define C_PRM1      0x0046      /* parameter 1 */
#define C_PRM2      0x0048      /* parameter 2 */
#define C_PRM3      0x004A      /* parameter 3 */
#define C_PRM4      0x004C      /* parameter 4 */
#define C_PRM5      0x004E      /* parameter 5 */
#define C_PRM6      0x0050      /* parameter 6 */
#define C_PRM7      0x0052      /* parameter 7 */
#define C_PRM8      0x0054      /* parameter 8 */
#define C_PRM9      0x0056      /* parameter 9 */
#define C_PRM10     0x0058      /* parameter 10 */
#define C_PRM11     0x005A      /* parameter 11 */
#define C_PRM12     0x005C      /* parameter 12 */
#define C_PRM13     0x005E      /* parameter 13 */
#define C_PRM14     0x0060      /* parameter 14 */
#define C_PRM15     0x0062      /* parameter 15 */

#define GLOBSTAT    0x0064      /* global status */
#define IMASK       0x0066      /* interrupt mask */
#define IFLAG       0x0068      /* interrupt flag */

#define PAGEREG 0x0080          /* dual ported memory page register */
#define CTRLREG 0x0082          /* control register */

#define EEPREG  0x00FE          /* identification EEPROM register */

/*
 * hardware register bit definitions
 */
#define HIRQ    0x0001  /* host interrupt request bit */
#define RESET   0x0004  /* local reset bit */
#define RDY     0x0008  /* ready bit, set by module cleared by host */
#define BOOT    0x0100  /* boot bit, boot selection */
#define CMDPAGE 0x0100  /* command structure resides at memory page 0x100 */


/*******************************************************************
 *
 * M392 Command Set
 *
 */
#define DONE        0x0000  /* command completed */
#define SYNC        0x5a5a  /* synchronize firmware, sign of live */
#define VERSION     0x1000  /* returns version information */
#define SETUP       0x0001  /* setup channel configuration */
#define SETACQTIME  0x0002  /* setup acquisition time */
#define MAFILTER    0x0003  /* configure moving average filter */

/*
 *command parameter definitions
 */

/* SYNC - synchronize firmware, sign of live
 *
 * VERSION - get version information
 *  parm0: module type, should be 392
 *  parm1: firmware version number
 *  parm2: reserved
 *  parm3: resolution: 16 or 12
 *
 * SETUP - setup channel configuration
 *  parm0: channel 0 control word
 *  parm1: channel 1 control word
 *  parm2: channel 2 control word
 *  parm3: channel 3 control word
 *  parm4: channel 4 control word
 *  parm5: channel 5 control word
 *  parm6: channel 6 control word
 *  parm7: channel 7 control word
 *  parm8: channel 8 control word
 *  parm9: channel 9 control word
 *  parm10: channel 10 control word
 *  parm11: channel 11 control word
 *  parm12: channel 12 control word
 *  parm13: channel 13 control word
 *  parm14: channel 14 control word
 *  parm15: channel 15 control word
 *
 * SETUPACQTIME - setup acquisition time
 *  parm0: acquisition time
 *
 * MAFILTER - configure moving average filter
 *  parm0: filter selection
 *
 */
#define MODTYPE     392    /* module type */
/* parameters SETUP */
#define V10BI       0x0000 /* control word +/- 10 V bipolar */
#define V10UNI      0x0001 /* control word 10 V unipolar */
#define V5BI        0x0002 /* control word +/- 5 V bipolar */
#define V5UNI       0x0003 /* control word 5 V unipolar */
#define DISCHAN     0x0004 /* control word channel disabled */
/* parameters MAFILTER */
#define DISFILT     0x0000 /* disable moving average filter */
#define SAMPLE8     0x0001 /* 8 samples */
#define SAMPLE16    0x0002 /* 16 samples */
#define SAMPLE32    0x0003 /* 32 samples (default) */
#define SAMPLE64    0x0004 /* 64 samples */
#define SAMPLE128   0x0005 /* 128 samples */
/* parameters SETUPACQTIME */
#define TIME20us    0x0000 /* 20 microseconds (default) */
#define TIME100us   0x0001 /* 100 microseconds */
#define TIME500us   0x0002 /* 500 microseconds */
#define TIME1000us  0x0003 /* 1000 microseconds */

/*
 * Command Result Codes
 */
#define NOERR       0x0000  /* no error */
#define UNKCMD      0x8001  /* ERROR: unknown command */
#define ADCFAIL     0x8002  /* ERROR: a-to-d converter failure */
#define ILLREQ      0x8003  /* ERROR: illegal request */

/* global status - bit definitions */
#define MODID_ERR   0x00001     /* Wrong module ID */
#define EEP_EMPTY   0x00002     /* ID eerpom not programmed */
#define EEP_CSERR   0x00004     /* ID eeprom checksum error */
#define EEP_FAULT   0x00008     /* ID eeprom access error */
#define CALMODE     0x00010     /* Module is in calibration mode */
#define FLASH_FAULT 0x00020     /* FLASH access error */


/*
 *external functions references
 */
/* booting m392 */
extern int m392_boot (APIS_HANDLE handle);
extern int m392_ramboot (APIS_HANDLE handle);
/* give command to m392 */
extern int m392_cmd (APIS_HANDLE handle, UINT16 command, UINT16 *pArgList,
                int ni, int no);
/* unmask interrupt and install interrupt handler */
extern int m392_install_irq( APIS_HANDLE handle);
/* mask interrupt and remove interrupt handler */
extern int m392_remove_irq( APIS_HANDLE handle);
/* interrupt handler */
extern int m392_irqh (APIS_HANDLE handle);
/* setup channel configuration */
extern int m392_setupchan(APIS_HANDLE handle, UINT16 *ctrlwrdlist);
/* setup all channels with same input range */
extern int m392_setupallchan(APIS_HANDLE handle, UINT16 cntlwrd);
/* setup acquisition time */
extern int m392_setupacqtime( APIS_HANDLE handle, UINT16 throughput);
/* configure moving average filter */
extern int m392_configmafilter( APIS_HANDLE handle, UINT16 filter_beh);
/* read data from a channel */
extern int m392_readchannel( APIS_HANDLE handle, UINT16 channel, UINT16 *data);
/* check RDY bit */
extern int m392_check_rdybit( APIS_HANDLE handle);
/* wait till RDY bit is set */
extern void m392_wait4rdybit( APIS_HANDLE handle);
/* clear RDY bit */
extern void m392_clear_rdybit( APIS_HANDLE handle);

/*
 * definitions for interrupt status
 */
#define SET 1
#define CLEAR 0

#endif /* __INCm392defsh */
